Type: Package
Package: ggiraph
Title: Make 'ggplot2' Graphics Interactive
Version: 0.9.6
Authors@R: c(
    person("David", "Gohel", , "david.gohel@ardata.fr", role = c("aut", "cre")),
    person("Panagiotis", "Skintzos", , "sigmapi@posteo.net", role = "aut"),
    person("Mike", "Bostock", role = "cph",
           comment = "d3.js"),
    person("Speros", "Kokenes", role = "cph",
           comment = "d3-lasso"),
    person("Eric", "Shull", role = "cph",
           comment = "saveSvgAsPng js library"),
    person("Lee", "Thomason", role = "cph",
           comment = "TinyXML2"),
    person("Vladimir", "Agafonkin", role = "cph",
           comment = "Flatbush"),
    person("Eric", "Book", role = "ctb",
           comment = "hline and vline geoms")
  )
Description: Create interactive 'ggplot2' graphics using 'htmlwidgets'.
License: GPL-3
URL: https://davidgohel.github.io/ggiraph/
BugReports: https://github.com/davidgohel/ggiraph/issues
Imports: cli, dplyr, gdtools (>= 0.5.0), ggplot2 (>= 4.0.0), grid,
        htmltools, htmlwidgets (>= 1.5), MASS, purrr, Rcpp (>= 1.1.0),
        rlang, S7 (>= 0.2.0), stats, systemfonts (>= 1.3.1), vctrs
Suggests: ggbeeswarm, ggrepel (>= 0.9.1), hexbin, knitr, maps,
        quantreg, rmarkdown, sf (>= 1.0), shiny, tinytest, xml2 (>=
        1.0)
LinkingTo: Rcpp, systemfonts
VignetteBuilder: knitr
Copyright: See file COPYRIGHTS.
Encoding: UTF-8
RoxygenNote: 7.3.3
SystemRequirements: libpng
Collate: 'RcppExports.R' 'ipar.R' 'utils_ggplot2_performance.R'
        'utils_ggplot2.R' 'utils.R' 'annotate_interactive.R'
        'annotation_raster_interactive.R' 'utils_css.R' 'fonts.R'
        'girafe_options.R' 'default.R' 'dsvg.R' 'dsvg_view.R'
        'element_interactive.R' 'facet_interactive.R'
        'geom_abline_interactive.R' 'geom_path_interactive.R'
        'geom_polygon_interactive.R' 'geom_rect_interactive.R'
        'geom_bar_interactive.R' 'geom_bin_2d_interactive.R'
        'geom_boxplot_interactive.R' 'geom_col_interactive.R'
        'geom_contour_interactive.R' 'geom_count_interactive.R'
        'geom_crossbar_interactive.R' 'geom_curve_interactive.R'
        'geom_density_2d_interactive.R' 'geom_density_interactive.R'
        'geom_dotplot_interactive.R' 'geom_errorbar_interactive.R'
        'geom_errorbarh_interactive.R' 'geom_freqpoly_interactive.R'
        'geom_hex_interactive.R' 'geom_histogram_interactive.R'
        'geom_hline_interactive.R' 'geom_jitter_interactive.R'
        'geom_label_interactive.R' 'geom_linerange_interactive.R'
        'geom_map_interactive.R' 'geom_point_interactive.R'
        'geom_pointrange_interactive.R' 'geom_quantile_interactive.R'
        'geom_quasirandom_interactive.R' 'geom_raster_interactive.R'
        'geom_ribbon_interactive.R' 'geom_segment_interactive.R'
        'geom_sf_interactive.R' 'geom_smooth_interactive.R'
        'geom_spoke_interactive.R' 'geom_text_interactive.R'
        'geom_text_repel_interactive.R' 'geom_tile_interactive.R'
        'geom_violin_interactive.R' 'geom_vline_interactive.R'
        'ggiraph.R' 'girafe.R' 'girafe_class.R' 'grob_interactive.R'
        'guide_bins_interactive.R' 'guide_colourbar_interactive.R'
        'guide_coloursteps_interactive.R' 'guide_interactive.R'
        'guide_legend_interactive.R' 'interactive_circle_grob.R'
        'interactive_curve_grob.R' 'interactive_path_grob.R'
        'interactive_points_grob.R' 'interactive_polygon_grob.R'
        'interactive_polyline_grob.R' 'interactive_raster_grob.R'
        'interactive_rect_grob.R' 'interactive_roundrect_grob.R'
        'interactive_segments_grob.R' 'interactive_text_grob.R'
        'labeller_interactive.R' 'layer_interactive.R'
        'scale_alpha_interactive.R' 'scale_brewer_interactive.R'
        'scale_colour_interactive.R' 'scale_gradient_interactive.R'
        'scale_interactive.R' 'scale_linetype_interactive.R'
        'scale_manual_interactive.R' 'scale_shape_interactive.R'
        'scale_size_interactive.R' 'scale_steps_interactive.R'
        'scale_viridis_interactive.R' 'tracers.R' 'utils_data.r'
NeedsCompilation: yes
Packaged: 2026-02-20 10:33:18 UTC; davidgohel
Author: David Gohel [aut, cre],
  Panagiotis Skintzos [aut],
  Mike Bostock [cph] (d3.js),
  Speros Kokenes [cph] (d3-lasso),
  Eric Shull [cph] (saveSvgAsPng js library),
  Lee Thomason [cph] (TinyXML2),
  Vladimir Agafonkin [cph] (Flatbush),
  Eric Book [ctb] (hline and vline geoms)
Maintainer: David Gohel <david.gohel@ardata.fr>
Repository: CRAN
Date/Publication: 2026-02-21 10:50:02 UTC
Built: R 4.6.0; aarch64-apple-darwin23; 2026-04-26 15:52:01 UTC; unix
Archs: ggiraph.so.dSYM
