# Generated by roxygen2: do not edit by hand

S3method(drawDetails,interactive_circle_grob)
S3method(drawDetails,interactive_lines_grob)
S3method(drawDetails,interactive_path_grob)
S3method(drawDetails,interactive_points_grob)
S3method(drawDetails,interactive_polygon_grob)
S3method(drawDetails,interactive_polyline_grob)
S3method(drawDetails,interactive_raster_grob)
S3method(drawDetails,interactive_rect_grob)
S3method(drawDetails,interactive_segments_grob)
S3method(drawDetails,interactive_text_grob)
S3method(drawDetails,interactive_xspline_grob)
S3method(element_grob,interactive_element)
S3method(element_grob,interactive_element_text)
S3method(makeContent,interactive_curve_grob)
S3method(makeContent,interactive_repeltree_grob)
S3method(makeContent,interactive_roundrect_grob)
S3method(makeContext,interactive_dotstack_grob)
S3method(merge_element,interactive_element)
export(FacetInteractiveGrid)
export(FacetInteractiveWrap)
export(GeomInteractiveAbline)
export(GeomInteractiveArea)
export(GeomInteractiveBar)
export(GeomInteractiveBoxplot)
export(GeomInteractiveCol)
export(GeomInteractiveContour)
export(GeomInteractiveContourFilled)
export(GeomInteractiveCrossbar)
export(GeomInteractiveCurve)
export(GeomInteractiveDensity)
export(GeomInteractiveDensity2d)
export(GeomInteractiveDensity2dFilled)
export(GeomInteractiveDotplot)
export(GeomInteractiveErrorbar)
export(GeomInteractiveErrorbarh)
export(GeomInteractiveHex)
export(GeomInteractiveHline)
export(GeomInteractiveLabel)
export(GeomInteractiveLine)
export(GeomInteractiveLinerange)
export(GeomInteractiveMap)
export(GeomInteractivePath)
export(GeomInteractivePoint)
export(GeomInteractivePointrange)
export(GeomInteractivePolygon)
export(GeomInteractiveQuantile)
export(GeomInteractiveRaster)
export(GeomInteractiveRasterAnn)
export(GeomInteractiveRect)
export(GeomInteractiveRibbon)
export(GeomInteractiveSegment)
export(GeomInteractiveSf)
export(GeomInteractiveSmooth)
export(GeomInteractiveSpoke)
export(GeomInteractiveStep)
export(GeomInteractiveText)
export(GeomInteractiveTile)
export(GeomInteractiveViolin)
export(GeomInteractiveVline)
export(GuideInteractiveBins)
export(GuideInteractiveColourbar)
export(GuideInteractiveColoursteps)
export(GuideInteractiveLegend)
export(StatInteractiveBoxplot)
export(annotate_interactive)
export(annotation_raster_interactive)
export(dsvg)
export(dsvg_view)
export(element_line_interactive)
export(element_rect_interactive)
export(element_text_interactive)
export(facet_grid_interactive)
export(facet_wrap_interactive)
export(geom_abline_interactive)
export(geom_area_interactive)
export(geom_bar_interactive)
export(geom_bin2d_interactive)
export(geom_bin_2d_interactive)
export(geom_boxplot_interactive)
export(geom_col_interactive)
export(geom_contour_filled_interactive)
export(geom_contour_interactive)
export(geom_count_interactive)
export(geom_crossbar_interactive)
export(geom_curve_interactive)
export(geom_density2d_filled_interactive)
export(geom_density2d_interactive)
export(geom_density_2d_filled_interactive)
export(geom_density_2d_interactive)
export(geom_density_interactive)
export(geom_dotplot_interactive)
export(geom_errorbar_interactive)
export(geom_errorbarh_interactive)
export(geom_freqpoly_interactive)
export(geom_hex_interactive)
export(geom_histogram_interactive)
export(geom_hline_interactive)
export(geom_jitter_interactive)
export(geom_label_interactive)
export(geom_label_repel_interactive)
export(geom_line_interactive)
export(geom_linerange_interactive)
export(geom_map_interactive)
export(geom_path_interactive)
export(geom_point_interactive)
export(geom_pointrange_interactive)
export(geom_polygon_interactive)
export(geom_quantile_interactive)
export(geom_quasirandom_interactive)
export(geom_raster_interactive)
export(geom_rect_interactive)
export(geom_ribbon_interactive)
export(geom_segment_interactive)
export(geom_sf_interactive)
export(geom_sf_label_interactive)
export(geom_sf_text_interactive)
export(geom_smooth_interactive)
export(geom_spoke_interactive)
export(geom_step_interactive)
export(geom_text_interactive)
export(geom_text_repel_interactive)
export(geom_tile_interactive)
export(geom_violin_interactive)
export(geom_vline_interactive)
export(ggiraph)
export(ggiraphOutput)
export(girafe)
export(girafeOutput)
export(girafe_class_add)
export(girafe_class_remove)
export(girafe_class_toggle)
export(girafe_css)
export(girafe_css_bicolor)
export(girafe_defaults)
export(girafe_options)
export(guide_bins_interactive)
export(guide_colorbar_interactive)
export(guide_colorsteps_interactive)
export(guide_colourbar_interactive)
export(guide_coloursteps_interactive)
export(guide_legend_interactive)
export(init_girafe_defaults)
export(interactive_circle_grob)
export(interactive_curve_grob)
export(interactive_lines_grob)
export(interactive_path_grob)
export(interactive_points_grob)
export(interactive_polygon_grob)
export(interactive_polyline_grob)
export(interactive_raster_grob)
export(interactive_rect_grob)
export(interactive_roundrect_grob)
export(interactive_segments_grob)
export(interactive_text_grob)
export(label_interactive)
export(labeller_interactive)
export(match_family)
export(opts_hover)
export(opts_hover_inv)
export(opts_hover_key)
export(opts_hover_theme)
export(opts_selection)
export(opts_selection_inv)
export(opts_selection_key)
export(opts_selection_theme)
export(opts_sizing)
export(opts_toolbar)
export(opts_tooltip)
export(opts_zoom)
export(renderGirafe)
export(renderggiraph)
export(run_girafe_example)
export(scale_alpha_binned_interactive)
export(scale_alpha_continuous_interactive)
export(scale_alpha_date_interactive)
export(scale_alpha_datetime_interactive)
export(scale_alpha_discrete_interactive)
export(scale_alpha_interactive)
export(scale_alpha_manual_interactive)
export(scale_alpha_ordinal_interactive)
export(scale_color_binned_interactive)
export(scale_color_brewer_interactive)
export(scale_color_continuous_interactive)
export(scale_color_date_interactive)
export(scale_color_datetime_interactive)
export(scale_color_discrete_interactive)
export(scale_color_distiller_interactive)
export(scale_color_fermenter_interactive)
export(scale_color_gradient2_interactive)
export(scale_color_gradient_interactive)
export(scale_color_gradientn_interactive)
export(scale_color_grey_interactive)
export(scale_color_hue_interactive)
export(scale_color_manual_interactive)
export(scale_color_ordinal_interactive)
export(scale_color_steps2_interactive)
export(scale_color_steps_interactive)
export(scale_color_stepsn_interactive)
export(scale_color_viridis_b_interactive)
export(scale_color_viridis_c_interactive)
export(scale_color_viridis_d_interactive)
export(scale_colour_binned_interactive)
export(scale_colour_brewer_interactive)
export(scale_colour_continuous_interactive)
export(scale_colour_date_interactive)
export(scale_colour_datetime_interactive)
export(scale_colour_discrete_interactive)
export(scale_colour_distiller_interactive)
export(scale_colour_fermenter_interactive)
export(scale_colour_gradient2_interactive)
export(scale_colour_gradient_interactive)
export(scale_colour_gradientn_interactive)
export(scale_colour_grey_interactive)
export(scale_colour_hue_interactive)
export(scale_colour_manual_interactive)
export(scale_colour_ordinal_interactive)
export(scale_colour_steps2_interactive)
export(scale_colour_steps_interactive)
export(scale_colour_stepsn_interactive)
export(scale_colour_viridis_b_interactive)
export(scale_colour_viridis_c_interactive)
export(scale_colour_viridis_d_interactive)
export(scale_discrete_manual_interactive)
export(scale_fill_binned_interactive)
export(scale_fill_brewer_interactive)
export(scale_fill_continuous_interactive)
export(scale_fill_date_interactive)
export(scale_fill_datetime_interactive)
export(scale_fill_discrete_interactive)
export(scale_fill_distiller_interactive)
export(scale_fill_fermenter_interactive)
export(scale_fill_gradient2_interactive)
export(scale_fill_gradient_interactive)
export(scale_fill_gradientn_interactive)
export(scale_fill_grey_interactive)
export(scale_fill_hue_interactive)
export(scale_fill_manual_interactive)
export(scale_fill_ordinal_interactive)
export(scale_fill_steps2_interactive)
export(scale_fill_steps_interactive)
export(scale_fill_stepsn_interactive)
export(scale_fill_viridis_b_interactive)
export(scale_fill_viridis_c_interactive)
export(scale_fill_viridis_d_interactive)
export(scale_linetype_binned_interactive)
export(scale_linetype_continuous_interactive)
export(scale_linetype_discrete_interactive)
export(scale_linetype_interactive)
export(scale_linetype_manual_interactive)
export(scale_radius_interactive)
export(scale_shape_binned_interactive)
export(scale_shape_continuous_interactive)
export(scale_shape_discrete_interactive)
export(scale_shape_interactive)
export(scale_shape_manual_interactive)
export(scale_shape_ordinal_interactive)
export(scale_size_area_interactive)
export(scale_size_binned_area_interactive)
export(scale_size_binned_interactive)
export(scale_size_continuous_interactive)
export(scale_size_date_interactive)
export(scale_size_datetime_interactive)
export(scale_size_discrete_interactive)
export(scale_size_interactive)
export(scale_size_manual_interactive)
export(scale_size_ordinal_interactive)
export(set_girafe_defaults)
export(validated_fonts)
import(ggplot2)
import(graphics)
import(grid)
importFrom(MASS,kde2d)
importFrom(Rcpp,sourceCpp)
importFrom(S7,prop_exists)
importFrom(dplyr,consecutive_id)
importFrom(dplyr,filter)
importFrom(dplyr,group_by)
importFrom(dplyr,lag)
importFrom(dplyr,mutate)
importFrom(dplyr,ungroup)
importFrom(gdtools,font_family_exists)
importFrom(gdtools,font_set_liberation)
importFrom(gdtools,sys_fonts)
importFrom(grDevices,dev.cur)
importFrom(grDevices,dev.list)
importFrom(grDevices,dev.off)
importFrom(grid,makeContext)
importFrom(htmltools,HTML)
importFrom(htmltools,browsable)
importFrom(htmltools,htmlDependency)
importFrom(htmltools,htmlEscape)
importFrom(htmlwidgets,createWidget)
importFrom(htmlwidgets,shinyRenderWidget)
importFrom(htmlwidgets,shinyWidgetOutput)
importFrom(htmlwidgets,sizingPolicy)
importFrom(purrr,detect_index)
importFrom(purrr,flatten)
importFrom(purrr,imap)
importFrom(purrr,transpose)
importFrom(rlang,"%||%")
importFrom(rlang,abort)
importFrom(rlang,arg_match)
importFrom(rlang,caller_env)
importFrom(rlang,current_env)
importFrom(rlang,env_get_list)
importFrom(rlang,eval_tidy)
importFrom(rlang,format_error_call)
importFrom(rlang,inherits_any)
importFrom(rlang,inject)
importFrom(rlang,is_named)
importFrom(rlang,is_null)
importFrom(rlang,is_scalar_character)
importFrom(rlang,is_scalar_double)
importFrom(rlang,is_scalar_integer)
importFrom(rlang,is_scalar_logical)
importFrom(rlang,is_string)
importFrom(rlang,list2)
importFrom(rlang,zap)
importFrom(stats,ave)
importFrom(stats,complete.cases)
importFrom(stats,setNames)
importFrom(systemfonts,match_font)
importFrom(systemfonts,registry_fonts)
importFrom(systemfonts,system_fonts)
importFrom(vctrs,data_frame)
importFrom(vctrs,list_sizes)
importFrom(vctrs,vec_cast)
importFrom(vctrs,vec_cbind)
importFrom(vctrs,vec_interleave)
importFrom(vctrs,vec_ptype2)
importFrom(vctrs,vec_rbind)
importFrom(vctrs,vec_slice)
importFrom(vctrs,vec_unique)
useDynLib(ggiraph,.registration = TRUE)
