This Shiny application demonstrates how to call a JavaScript function with aesthetic `onclick`. 
When a point is clicked, its label is written to the DataTables filter area.

JavaScript function `set_search_val` is defined in file `set_search_val.js`. 

A column containing JavaScript calls is used to map aesthetic `onclick`. The corresponding call 
will be executed when a point will be clicked.


