This Shiny application demonstrates `girafe_class_add()`, `girafe_class_remove()` and `girafe_class_toggle()`.

Use the text input to type a state name (e.g. "florida"), then click
"Add class", "Remove class" or "Toggle class" to manipulate the
`highlighted` CSS class on the corresponding point.
