Shiny application for linked interactive legend

Hover and selection are linked between legend keys and geometry points using
`opts_hover(linked = TRUE)` and `opts_selection(linked = TRUE)`.
Clicking a legend key selects the corresponding points and vice versa.
A summary of the selection is rendered.
