library(tinytest)
library(ggiraph)
library(ggplot2)
source("setup.R")

# scale_colour_interactive ----
{
  eval(test_scale, envir = list(name = "scale_colour_continuous_interactive"))
  eval(test_scale, envir = list(name = "scale_color_continuous_interactive"))
  eval(test_scale, envir = list(name = "scale_fill_continuous_interactive"))
  eval(test_scale, envir = list(name = "scale_colour_grey_interactive"))
  eval(test_scale, envir = list(name = "scale_color_grey_interactive"))
  eval(test_scale, envir = list(name = "scale_fill_grey_interactive"))
  eval(test_scale, envir = list(name = "scale_colour_hue_interactive"))
  eval(test_scale, envir = list(name = "scale_color_hue_interactive"))
  eval(test_scale, envir = list(name = "scale_fill_hue_interactive"))
  eval(test_scale, envir = list(name = "scale_colour_binned_interactive"))
  eval(test_scale, envir = list(name = "scale_color_binned_interactive"))
  eval(test_scale, envir = list(name = "scale_fill_binned_interactive"))
  eval(test_scale, envir = list(name = "scale_colour_discrete_interactive"))
  eval(test_scale, envir = list(name = "scale_color_discrete_interactive"))
  eval(test_scale, envir = list(name = "scale_fill_discrete_interactive"))
  eval(test_scale, envir = list(name = "scale_colour_date_interactive"))
  eval(test_scale, envir = list(name = "scale_color_date_interactive"))
  eval(test_scale, envir = list(name = "scale_fill_date_interactive"))
  eval(test_scale, envir = list(name = "scale_colour_datetime_interactive"))
  eval(test_scale, envir = list(name = "scale_color_datetime_interactive"))
  eval(test_scale, envir = list(name = "scale_fill_datetime_interactive"))
}
